Struct fuzzcheck::mutators::integer::ISizeMutator [−][src]
pub struct ISizeMutator { /* fields omitted */ }Trait Implementations
type MutationStep: Clone
type MutationStep: Clone
Contains information about what mutations have already been tried.
type ArbitraryStep: Clone
type ArbitraryStep: Clone
Contains information about what arbitrary values have already been generated.
type UnmutateToken
type UnmutateToken
Describes how to reverse a mutation
The first ArbitraryStep value to be passed to ordered_arbitrary
Returns the first MutationStep associated with the value
and cache. Read more
The maximum complexity that a value can possibly have. Read more
The minimum complexity that a value can possibly have. Read more
Computes the complexity of the value. Read more
fn ordered_arbitrary(
&self,
step: &mut Self::ArbitraryStep,
max_cplx: f64
) -> Option<(Value, f64)>
fn ordered_arbitrary(
&self,
step: &mut Self::ArbitraryStep,
max_cplx: f64
) -> Option<(Value, f64)>
Generates an entirely new value based on the given ArbitraryStep. Read more
Generates an entirely new value. Read more
fn ordered_mutate(
&self,
value: &mut Value,
cache: &mut Self::Cache,
step: &mut Self::MutationStep,
max_cplx: f64
) -> Option<(Self::UnmutateToken, f64)>
fn ordered_mutate(
&self,
value: &mut Value,
cache: &mut Self::Cache,
step: &mut Self::MutationStep,
max_cplx: f64
) -> Option<(Self::UnmutateToken, f64)>
Mutates a value (and optionally its cache) based on the given
MutationStep. Read more
fn random_mutate(
&self,
value: &mut Value,
cache: &mut Self::Cache,
max_cplx: f64
) -> (Self::UnmutateToken, f64)
fn random_mutate(
&self,
value: &mut Value,
cache: &mut Self::Cache,
max_cplx: f64
) -> (Self::UnmutateToken, f64)
Mutates a value (and optionally its cache). Read more
Undoes a mutation performed on the given value and cache, described by
the given UnmutateToken. Read more
type RecursingPartIndex: Clone
fn default_recursing_part_index(
&self,
value: &Value,
cache: &Self::Cache
) -> Self::RecursingPartIndex
fn recursing_part<'a, T, M>(
&self,
parent: &M,
value: &'a Value,
index: &mut Self::RecursingPartIndex
) -> Option<&'a T> where
T: Clone + 'static,
M: Mutator<T>,