pub struct Tuple10<T0: 'static, T1: 'static, T2: 'static, T3: 'static, T4: 'static, T5: 'static, T6: 'static, T7: 'static, T8: 'static, T9: 'static> { /* fields omitted */ }
A marker type implementing RefTypes indicating that a type has the structure of a 10-tuple.
impl<T0: 'static, T1: 'static, T2: 'static, T3: 'static, T4: 'static, T5: 'static, T6: 'static, T7: 'static, T8: 'static, T9: 'static> RefTypes for Tuple10<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9>
impl<T, T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, M0, M1, M2, M3, M4, M5, M6, M7, M8, M9> TupleMutator<T, Tuple10<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9>> for Tuple10Mutator<M0, M1, M2, M3, M4, M5, M6, M7, M8, M9> where
T: Clone + 'static,
T0: Clone + 'static,
M0: Mutator<T0>,
T1: Clone + 'static,
M1: Mutator<T1>,
T2: Clone + 'static,
M2: Mutator<T2>,
T3: Clone + 'static,
M3: Mutator<T3>,
T4: Clone + 'static,
M4: Mutator<T4>,
T5: Clone + 'static,
M5: Mutator<T5>,
T6: Clone + 'static,
M6: Mutator<T6>,
T7: Clone + 'static,
M7: Mutator<T7>,
T8: Clone + 'static,
M8: Mutator<T8>,
T9: Clone + 'static,
M9: Mutator<T9>,
T: TupleStructure<Tuple10<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9>>,
impl<T0: 'static, T1: 'static, T2: 'static, T3: 'static, T4: 'static, T5: 'static, T6: 'static, T7: 'static, T8: 'static, T9: 'static> TupleStructure<Tuple10<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9)
impl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9> Send for Tuple10<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9> where
T0: Send,
T1: Send,
T2: Send,
T3: Send,
T4: Send,
T5: Send,
T6: Send,
T7: Send,
T8: Send,
T9: Send,
impl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9> Sync for Tuple10<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9> where
T0: Sync,
T1: Sync,
T2: Sync,
T3: Sync,
T4: Sync,
T5: Sync,
T6: Sync,
T7: Sync,
T8: Sync,
T9: Sync,
impl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9> Unpin for Tuple10<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9> where
T0: Unpin,
T1: Unpin,
T2: Unpin,
T3: Unpin,
T4: Unpin,
T5: Unpin,
T6: Unpin,
T7: Unpin,
T8: Unpin,
T9: Unpin,
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.