pub struct Tuple4Mutator<M0, M1, M2, M3> { /* fields omitted */ }
A TupleMutator for types that have a 4-tuple structure
Returns the “default value” for a type. Read more
impl<T, T0, T1, T2, T3, M0, M1, M2, M3> TupleMutator<T, Tuple4<T0, T1, T2, T3>> for Tuple4Mutator<M0, M1, M2, M3> where
T: Clone + 'static,
T0: Clone + 'static,
M0: Mutator<T0>,
T1: Clone + 'static,
M1: Mutator<T1>,
T2: Clone + 'static,
M2: Mutator<T2>,
T3: Clone + 'static,
M3: Mutator<T3>,
T: TupleStructure<Tuple4<T0, T1, T2, T3>>,
impl<M0, M1, M2, M3> Send for Tuple4Mutator<M0, M1, M2, M3> where
M0: Send,
M1: Send,
M2: Send,
M3: Send,
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.