pub struct Tuple6<T0: 'static, T1: 'static, T2: 'static, T3: 'static, T4: 'static, T5: 'static> { /* fields omitted */ }
A marker type implementing RefTypes indicating that a type has the structure of a 6-tuple.
impl<T0: 'static, T1: 'static, T2: 'static, T3: 'static, T4: 'static, T5: 'static> RefTypes for Tuple6<T0, T1, T2, T3, T4, T5>
impl<T, T0, T1, T2, T3, T4, T5, M0, M1, M2, M3, M4, M5> TupleMutator<T, Tuple6<T0, T1, T2, T3, T4, T5>> for Tuple6Mutator<M0, M1, M2, M3, M4, M5> where
T: Clone + 'static,
T0: Clone + 'static,
M0: Mutator<T0>,
T1: Clone + 'static,
M1: Mutator<T1>,
T2: Clone + 'static,
M2: Mutator<T2>,
T3: Clone + 'static,
M3: Mutator<T3>,
T4: Clone + 'static,
M4: Mutator<T4>,
T5: Clone + 'static,
M5: Mutator<T5>,
T: TupleStructure<Tuple6<T0, T1, T2, T3, T4, T5>>,
impl<T0: 'static, T1: 'static, T2: 'static, T3: 'static, T4: 'static, T5: 'static> TupleStructure<Tuple6<T0, T1, T2, T3, T4, T5>> for (T0, T1, T2, T3, T4, T5)
impl<T0, T1, T2, T3, T4, T5> Send for Tuple6<T0, T1, T2, T3, T4, T5> where
T0: Send,
T1: Send,
T2: Send,
T3: Send,
T4: Send,
T5: Send,
impl<T0, T1, T2, T3, T4, T5> Sync for Tuple6<T0, T1, T2, T3, T4, T5> where
T0: Sync,
T1: Sync,
T2: Sync,
T3: Sync,
T4: Sync,
T5: Sync,
impl<T0, T1, T2, T3, T4, T5> Unpin for Tuple6<T0, T1, T2, T3, T4, T5> where
T0: Unpin,
T1: Unpin,
T2: Unpin,
T3: Unpin,
T4: Unpin,
T5: Unpin,
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.