pub trait RefTypes {
type Owned;
type Ref<'a>: Copy;
type Mut<'a>;
// Required method
fn get_ref_from_mut<'a>(v: &'a Self::Mut<'a>) -> Self::Ref<'a>;
}Expand description
A trait which essentially holds the types of a destructured tuple or structure.
Read the module documentation for more information about it.
Required Associated Types
Required Methods
fn get_ref_from_mut<'a>(v: &'a Self::Mut<'a>) -> Self::Ref<'a>
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.