Struct FuzzingResult

pub struct FuzzingResult<T> {
    pub found_test_failure: bool,
    pub reason_for_stopping: ReasonForStopping<T>,
}
The result of a fuzz test, if it ends.

It contains two fields:

  1. found_test_failure is true if the fuzzer found any failing test case
  2. reason_for_stopping gives the reason why the fuzzer stopped.

If the fuzzer stopped because it found a failing test case, then reason_for_stopping has the value ReasonForStopping::TestFailure(T) where T is the failing test case.

Fields

found_test_failure: boolreason_for_stopping: ReasonForStopping<T>