Struct StringSerializer

pub struct StringSerializer<StringType>
where StringType: ToString + FromStr,
{ pub extension: &'static str, /* private fields */ }
A serializer that encodes and decodes values of any type implementing FromStr and ToString into utf-8 encoded text files.

Fields

extension: &'static str

Implementations

Source

impl<StringType> StringSerializer<StringType>
where StringType: ToString + FromStr,

pub fn new(extension: &'static str) -> Self

Create a string serializer. The only argument is the name of the extension that the created files should have. For example:

use fuzzcheck::StringSerializer;

let ser = StringSerializer::<String>::new("txt");