Module subvalue_provider

Subvalue providers are used by mutators. They help generate interesting test cases by mixing parts of differents values together.

See the documentation of the Mutator trait for more informatiom.

Structs

CrossoverSubValueProvider
A SubValueProvider created from the subvalues of a particular test case.
EmptySubValueProvider
A SubValueProvider that always return None
Generation
See: SubValueProviderId
SubValueProviderId
Uniquely identifies a SubValueProvider

Traits

SubValueProvider
An object-safe trait which can give values of arbitrary types.