Module fuzzcheck::mutators[][src]

This crate provides a range of mutators that can be used to run structure-aware fuzz tests using the fuzzcheck crate. It also provides the DefaultMutator trait, which assigns a default mutator to a type:

use fuzzcheck::DefaultMutator;
let mutator = <Vec<Vec<Option<Box<u16>>>>>::default_mutator();

The following procedural macros are provided:

This crate provides grammar-based string mutators.

Modules

Macros

Make a mutator for a custom type, optionally making it the type’s default mutator. The syntax is as follows:

Traits

Derive Macros