pub struct FuzzingResult<T> {
pub found_test_failure: bool,
pub reason_for_stopping: ReasonForStopping<T>,
}Expand description
The result of a fuzz test, if it ends.
It contains two fields:
found_test_failureistrueif the fuzzer found any failing test casereason_for_stoppinggives the reason why the fuzzer stopped.
If the fuzzer stopped because it found a failing test case, then reason_for_stopping has the
value ReasonForStopping::TestFailure(T) where T is the
failing test case.
Fields
found_test_failure: boolreason_for_stopping: ReasonForStopping<T>Trait Implementations
Sourceimpl<T: Clone> Clone for FuzzingResult<T>
impl<T: Clone> Clone for FuzzingResult<T>
Sourcefn clone(&self) -> FuzzingResult<T>
fn clone(&self) -> FuzzingResult<T>
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl<T> Freeze for FuzzingResult<T>where
T: Freeze,
impl<T> RefUnwindSafe for FuzzingResult<T>where
T: RefUnwindSafe,
impl<T> Send for FuzzingResult<T>where
T: Send,
impl<T> Sync for FuzzingResult<T>where
T: Sync,
impl<T> Unpin for FuzzingResult<T>where
T: Unpin,
impl<T> UnwindSafe for FuzzingResult<T>where
T: UnwindSafe,