Trait fuzzcheck::Pool [−][src]
pub trait Pool: SaveToStatsFolder {
type Stats: Stats;
fn stats(&self) -> Self::Stats;
fn get_random_index(&mut self) -> Option<PoolStorageIndex>;
}Expand description
A Pool ranks test cases based on observations recorded by a sensor.
The pool trait is divided into two parts:
Poolcontains general methods that are independent of the sensor usedCompatibleWithSensor<Sensor>is a subtrait ofPool. It describes how the pool handles observations made by theSensor.
Associated Types
Required methods
fn get_random_index(&mut self) -> Option<PoolStorageIndex>
fn get_random_index(&mut self) -> Option<PoolStorageIndex>
Get the index of a random test case.
Most Pool implementations will want to prioritise certain test cases over others based on their associated observations.