pub trait Serializer {
type Value;
// Required methods
fn extension(&self) -> &str;
fn from_data(&self, data: &[u8]) -> Option<Self::Value>;
fn to_data(&self, value: &Self::Value) -> Vec<u8> ⓘ;
}Expand description
A Serializer is used to encode and decode test cases into bytes.
It is used to transfer test cases between the corpus on the file system and the fuzzer’s storage.